Name:           mana
Version:        0.6.1
Release:        6%{?dist}
Summary:        Open source 2D MMORPG platform client
License:        GPLv2+
Url:            http://manasource.org/
Source0:        http://manasource.org/files/%{name}-%{version}.tar.gz
# Upstream fix that allows compiling with cpp0x off to prevent issues with
# binary incompatibility of guichan that is not compiled with cpp0x
Patch0:         mana-fix-cpp0x-disabling.patch
# Fixes incorrect-fsf-address. 
# See https://github.com/mana/mana/commit/78c5784861c2d12a572ebce312f4a325d5dcd499
# for upstream fix.
Patch1:         mana-incorrect-fsf-address-fix.patch
# Fixes file-not-utf8 for AUTHORS file.
# See https://github.com/mana/mana/commit/7c13687e7af7f3d39f0f7c11b27bfab4f85204fa
# for upstream fix.
Patch2:         mana-utf8-authors-fix.patch
# Fixes the CXX flags getting overwritten by projects cmake files
# See https://github.com/mana/mana/commit/2305ca095bee6b32c930f71b99d4c1205ceb561b
# for upstream fix.
Patch3:         mana-dont-overwrite-system-flags-fix.patch
Requires:       dejavu-sans-fonts
Requires:       dejavu-sans-mono-fonts
BuildRequires:  cmake
BuildRequires:  dejavu-sans-fonts
BuildRequires:  dejavu-sans-mono-fonts
BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  guichan-devel
BuildRequires:  libcurl-devel
BuildRequires:  libpng-devel
BuildRequires:  physfs-devel
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  SDL_gfx-devel
BuildRequires:  SDL_image-devel
BuildRequires:  SDL_mixer-devel
BuildRequires:  SDL_net-devel
BuildRequires:  SDL_ttf-devel

%description
The Mana client is developed as part of The Mana Project, which aims to build
a complete 2D MMORPG platform. This includes a client, server and web
component, as well as a library of free content that you can use under the
terms of the GPL.

This version of the client can connect to a specific version of the eAthena
server known as tmwAthena, a version with adaptations made as part of The Mana
World project.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

# We will build without bundeled enet. To make sure it will be removed.
rm -rf  libs/enet

%build
%cmake -DWITH_OPENGL=ON -DCMAKE_INSTALL_PREFIX=%{_prefix} -DENABLE_CPP0X=OFF .
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot}
desktop-file-validate %{buildroot}/%{_datadir}/applications/%{name}.desktop

# Use system font
rm -f %{buildroot}/%{_datadir}/%{name}/data/fonts/dejavusans.ttf
rm -f %{buildroot}/%{_datadir}/%{name}/data/fonts/dejavusans-bold.ttf
rm -f %{buildroot}/%{_datadir}/%{name}/data/fonts/dejavusans-mono.ttf
ln -s %{_datadir}/fonts/dejavu/DejaVuSans.ttf %{buildroot}/%{_datadir}/%{name}/data/fonts/dejavusans.ttf
ln -s %{_datadir}/fonts/dejavu/DejaVuSans-Bold.ttf %{buildroot}/%{_datadir}/%{name}/data/fonts/dejavusans-bold.ttf
ln -s %{_datadir}/fonts/dejavu/DejaVuSansMono.ttf %{buildroot}/%{_datadir}/%{name}/data/fonts/dejavusans-mono.ttf

# Install manpage
install -D -p -m644 docs/%{name}.6 %{buildroot}/%{_mandir}/man6/%{name}.6
rm -f docs/%{name}.6

%find_lang %{name}

%files -f %{name}.lang
%doc AUTHORS ChangeLog COPYING docs/* NEWS README
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man6/%{name}.6*

%changelog
* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Sep 3 2012 Erik Schilling <ablu.erikschilling@googlemail.com> 0.6.1-5
- Fixed permissions in install command.

* Tue Aug 28 2012 Erik Schilling <ablu.erikschilling@googlemail.com> 0.6.1-4
- Changed "Opensource" -> "Open source".
- Fixed use of %% in changelog.
- Removed unessecary use of %%{buildroot}.
- Fixed packaging of the manpage.
- Changed last remaining $RPM_BUIL_ROOT to %%{buildroot}.

* Mon Aug 27 2012 Erik Schilling <ablu.erikschilling@googlemail.com> 0.6.1-3
- Made sure enet is removed.
- Turned mana.lang -> %%{mana}.lang.
- Added missing changelog entry.
- Fixed use of %%{optflags} Thanks to rdieter on IRC for help.

* Sun Aug 26 2012 Erik Schilling <ablu.erikschilling@googlemail.com> 0.6.1-2
- Made use of the %%cmake macro.
- Fixed release number + added %%{?dist}.
- Dropped BuildRoot tag.
- Added desktop-file-validate check.
- Replaced occurrences of mana with %%{name}.
- Dropped %%defattr line.

* Sun Aug 26 2012 Erik Schilling <ablu.erikschilling@googlemail.com> 0.6.1-1
- First version for official fedora repos.
